@@ -94,7 +94,7 @@ class McModel(object):
         value = []
         for i in self._fields:
             value.append(self.__dict__.get(i, None))
-        value = dumps(value)
+        value = dumps(tuple(value))
         mc.set(key, value)
 
     def __setattr__(self, name, value):
